==> zio-aws-applicationautoscaling_3-5.17.130.7-sources.jar: zio/aws/applicationautoscaling/model/DescribeScalingPoliciesRequest.scala <==
package zio.aws.applicationautoscaling.model
import java.lang.Integer
import zio.aws.applicationautoscaling.model.primitives.{
  XmlString,
  MaxResults,
  ResourceIdMaxLen1600
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeScalingPoliciesRequest(
    policyNames: Option[Iterable[ResourceIdMaxLen1600]] = None,
    serviceNamespace: zio.aws.applicationautoscaling.model.ServiceNamespace,
    resourceId: Option[ResourceIdMaxLen1600] = None,
    scalableDimension: Option[
      zio.aws.applicationautoscaling.model.ScalableDimension
    ] = None,
    maxResults: Option[MaxResults] = None,
    nextToken: Option[XmlString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest = {
    import DescribeScalingPoliciesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest
      .builder()
      .optionallyWith(
        policyNames.map(value =>
          value.map { item =>
            ResourceIdMaxLen1600.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.policyNames)
      .serviceNamespace(serviceNamespace.unwrap)
      .optionallyWith(
        resourceId.map(value =>
          ResourceIdMaxLen1600.unwrap(value): java.lang.String
        )
      )(_.resourceId)
      .optionallyWith(scalableDimension.map(value => value.unwrap))(
        _.scalableDimension
      )
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => XmlString.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest.ReadOnly =
    zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest
      .wrap(buildAwsValue())
}
object DescribeScalingPoliciesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest =
      zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest(
        policyNames.map(value => value),
        serviceNamespace,
        resourceId.map(value => value),
        scalableDimension.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def policyNames: Option[List[ResourceIdMaxLen1600]]
    def serviceNamespace: zio.aws.applicationautoscaling.model.ServiceNamespace
    def resourceId: Option[ResourceIdMaxLen1600]
    def scalableDimension
        : Option[zio.aws.applicationautoscaling.model.ScalableDimension]
    def maxResults: Option[MaxResults]
    def nextToken: Option[XmlString]
    def getPolicyNames: ZIO[Any, AwsError, List[ResourceIdMaxLen1600]] =
      AwsError.unwrapOptionField("policyNames", policyNames)
    def getServiceNamespace: ZIO[
      Any,
      Nothing,
      zio.aws.applicationautoscaling.model.ServiceNamespace
    ] = ZIO.succeed(serviceNamespace)
    def getResourceId: ZIO[Any, AwsError, ResourceIdMaxLen1600] =
      AwsError.unwrapOptionField("resourceId", resourceId)
    def getScalableDimension: ZIO[
      Any,
      AwsError,
      zio.aws.applicationautoscaling.model.ScalableDimension
    ] = AwsError.unwrapOptionField("scalableDimension", scalableDimension)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, XmlString] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest
  ) extends zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest.ReadOnly {
    override val policyNames: Option[List[ResourceIdMaxLen1600]] = scala
      .Option(impl.policyNames())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.applicationautoscaling.model.primitives
            .ResourceIdMaxLen1600(item)
        }.toList
      )
    override val serviceNamespace
        : zio.aws.applicationautoscaling.model.ServiceNamespace =
      zio.aws.applicationautoscaling.model.ServiceNamespace
        .wrap(impl.serviceNamespace())
    override val resourceId: Option[ResourceIdMaxLen1600] = scala
      .Option(impl.resourceId())
      .map(value =>
        zio.aws.applicationautoscaling.model.primitives
          .ResourceIdMaxLen1600(value)
      )
    override val scalableDimension
        : Option[zio.aws.applicationautoscaling.model.ScalableDimension] = scala
      .Option(impl.scalableDimension())
      .map(value =>
        zio.aws.applicationautoscaling.model.ScalableDimension.wrap(value)
      )
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.applicationautoscaling.model.primitives.MaxResults(value)
      )
    override val nextToken: Option[XmlString] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.applicationautoscaling.model.primitives.XmlString(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest
  ): zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-applicationautoscaling_3-5.17.190.1-sources.jar: zio/aws/applicationautoscaling/model/DescribeScalingPoliciesRequest.scala <==
package zio.aws.applicationautoscaling.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.applicationautoscaling.model.primitives.{
  XmlString,
  MaxResults,
  ResourceIdMaxLen1600
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class DescribeScalingPoliciesRequest(
    policyNames: Optional[Iterable[ResourceIdMaxLen1600]] = Optional.Absent,
    serviceNamespace: zio.aws.applicationautoscaling.model.ServiceNamespace,
    resourceId: Optional[ResourceIdMaxLen1600] = Optional.Absent,
    scalableDimension: Optional[
      zio.aws.applicationautoscaling.model.ScalableDimension
    ] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[XmlString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest = {
    import DescribeScalingPoliciesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest
      .builder()
      .optionallyWith(
        policyNames.map(value =>
          value.map { item =>
            ResourceIdMaxLen1600.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.policyNames)
      .serviceNamespace(serviceNamespace.unwrap)
      .optionallyWith(
        resourceId.map(value =>
          ResourceIdMaxLen1600.unwrap(value): java.lang.String
        )
      )(_.resourceId)
      .optionallyWith(scalableDimension.map(value => value.unwrap))(
        _.scalableDimension
      )
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => XmlString.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest.ReadOnly =
    zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest
      .wrap(buildAwsValue())
}
object DescribeScalingPoliciesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest =
      zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest(
        policyNames.map(value => value),
        serviceNamespace,
        resourceId.map(value => value),
        scalableDimension.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def policyNames: Optional[List[ResourceIdMaxLen1600]]
    def serviceNamespace: zio.aws.applicationautoscaling.model.ServiceNamespace
    def resourceId: Optional[ResourceIdMaxLen1600]
    def scalableDimension
        : Optional[zio.aws.applicationautoscaling.model.ScalableDimension]
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[XmlString]
    def getPolicyNames: ZIO[Any, AwsError, List[ResourceIdMaxLen1600]] =
      AwsError.unwrapOptionField("policyNames", policyNames)
    def getServiceNamespace: ZIO[
      Any,
      Nothing,
      zio.aws.applicationautoscaling.model.ServiceNamespace
    ] = ZIO.succeed(serviceNamespace)
    def getResourceId: ZIO[Any, AwsError, ResourceIdMaxLen1600] =
      AwsError.unwrapOptionField("resourceId", resourceId)
    def getScalableDimension: ZIO[
      Any,
      AwsError,
      zio.aws.applicationautoscaling.model.ScalableDimension
    ] = AwsError.unwrapOptionField("scalableDimension", scalableDimension)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, XmlString] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest
  ) extends zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest.ReadOnly {
    override val policyNames: Optional[List[ResourceIdMaxLen1600]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.policyNames())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.applicationautoscaling.model.primitives
              .ResourceIdMaxLen1600(item)
          }.toList
        )
    override val serviceNamespace
        : zio.aws.applicationautoscaling.model.ServiceNamespace =
      zio.aws.applicationautoscaling.model.ServiceNamespace
        .wrap(impl.serviceNamespace())
    override val resourceId: Optional[ResourceIdMaxLen1600] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resourceId())
        .map(value =>
          zio.aws.applicationautoscaling.model.primitives
            .ResourceIdMaxLen1600(value)
        )
    override val scalableDimension
        : Optional[zio.aws.applicationautoscaling.model.ScalableDimension] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scalableDimension())
        .map(value =>
          zio.aws.applicationautoscaling.model.ScalableDimension.wrap(value)
        )
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.applicationautoscaling.model.primitives.MaxResults(value)
      )
    override val nextToken: Optional[XmlString] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.applicationautoscaling.model.primitives.XmlString(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.applicationautoscaling.model.DescribeScalingPoliciesRequest
  ): zio.aws.applicationautoscaling.model.DescribeScalingPoliciesRequest.ReadOnly =
    new Wrapper(impl)
}
